@@ -1,6 +1,7 @@
 import json
 import requests
 from requests.exceptions import HTTPError
+from urllib import parse
 
 
 class CDN:
@@ -30,13 +31,13 @@ class CDN:
         """
         if Task_name[0] == "/":
             if Task_name[-1] == "/":
-                url = self.base_url + Task_name[1:-1]
+                url = self.base_url + parse.quote(Task_name[1:-1])
             else:
-                url = self.base_url + Task_name[1:]
+                url = self.base_url + parse.quote(Task_name[1:])
         elif Task_name[-1] == "/":
-            url = self.base_url + Task_name[1:-1]
+            url = self.base_url + parse.quote(Task_name[1:-1])
         else:
-            url = self.base_url + Task_name
+            url = self.base_url + parse.quote(Task_name)
         return url
 
     def AddCertificate(self,
@@ -1118,11 +1119,11 @@ class CDN:
                               The hostname that will be registered
 
         """
-        values = json.dumps({"PullZoneID": PullZoneID, "Hostname": Hostname})
+        values = json.dumps({"Hostname": Hostname})
 
         try:
             response = requests.post(
-                self._Geturl("pullzone/addHostname"),
+                self._Geturl(f"pullzone/{PullZoneID}/addHostname"),
                 data=values,
                 headers=self.headers
             )
@@ -1157,10 +1158,10 @@ class CDN:
                              The hostname that will be deleted
 
         """
-        params = {"id": PullZoneID, "hostname": Hostname}
+        params = {"hostname": Hostname}
         try:
             response = requests.delete(
-                self._Geturl("pullzone/deleteHostname"),
+                self._Geturl(f"pullzone/{PullZoneID}/removeHostname"),
                 params=params,
                 headers=self.headers,
             )
@@ -1200,13 +1201,12 @@ class CDN:
 
         """
         values = json.dumps(
-            {"PullZoneID": PullZoneID,
-             "Hostname": Hostname,
+            {"Hostname": Hostname,
              "ForceSSL": ForceSSL}
         )
         try:
             response = requests.post(
-                self._Geturl("pullzone/setForceSSL"),
+                self._Geturl(f"pullzone/{PullZoneID}/setForceSSL"),
                 data=values,
                 headers=self.headers
             )
@@ -1240,8 +1240,9 @@ class CDN:
         """
         try:
             response = requests.get(
-             self._Geturl(f"pullzone/loadFreeCertificate?hostname={Hostname}"),
-             headers=self.headers,
+                self._Geturl("pullzone/loadFreeCertificate"),
+                params={'hostname': Hostname},
+                headers=self.headers,
             )
             response.raise_for_status()
         except HTTPError as http:
